@@ -1,19 +1,20 @@
+"""
+This example is to demonstrate GooeyPy's widgets and functionality.
+"""
+
 import sys
-#sys.path.insert(0, "..")
+sys.path.insert(0, "..")
 
 import gooeypy as gui
 import pygame
-from pygame.locals import *
+from gooeypy.const import *
 
-# Our time tracker. A bit cooler than pygame's.
-clock = gui.Clock(fps_limit=30)
+# Our clock.
+clock = pygame.time.Clock()
 
 # Lets initialize the GUI.
 gui.init(640, 480)
 
-# And pygame.
-pygame.init()
-
 # Our base GUI widget, the mighty App!
 app = gui.App(width=640, height=480)
 
@@ -26,8 +27,11 @@ w4 = gui.HSlider(min_value=20, length=10, x=200, y=160)
 w9 = gui.VSlider(length=40, x=600, y=160, step=False)
 l1 = gui.Label(value="Pulsate:", x=395, y=30, font_size=25)
 
+data = "This example is to demonstrate GooeyPy's widgets and functionality."
+tb = gui.TextBlock(value=data, x=200, y=350, width=300)
+
 # Add our widgets to our App.
-app.add([w1,w2,w3,w4,w9,l1])
+app.add([w1,w2,w3,w4,w9,l1, tb])
 
 # Now lets make us a VBox, which will automatically position widgets inside of it
 # vertically. Give it an ugly bgcolor too for fun.
@@ -87,19 +91,19 @@ def callback():
 
 # Now we connect our switch to our call back with the event CHANGE (which is
 # fired when ever the widget changes).
-w3.connect(gui.CHANGE, callback)
+w3.connect(CHANGE, callback)
 
 
 # Lets make another connection just for fun.
 def callback():
     w2.value = "GooeyPy is cool!"
-w1.connect(gui.CLICK, callback)
+w1.connect(CLICK, callback)
 
 
 # Now lets run our app!
 quit = False
 while not quit:
-    clock.tick()
+    clock.tick(20)
 
     # We do this so we can share the events with the gui.
     events = pygame.event.get()
@@ -128,5 +132,5 @@ while not quit:
 # pygame.display.flip() if you are just updating parts of the screen. the
 # gui.blit() function takes care and adds it's blit rect to update_rects.
 #
-# Ok, that's all! Read the docs for more information about the widgets and
-# stuff.
+# Ok, that's all! You can read the docs for more information about the widgets,
+# styling and the like.
