@@ -392,11 +392,13 @@ class Widget(DependantCell):
                 #print self.__class__.__name__
 
                 x,y = self.pos
-                if self._last_blit_rect and self.parent:
+                # FIXME: won't work if widget doesn't have container... but
+                # fixes the x=y=0 display bug.
+                if self._last_blit_rect and self.container:
                     lbrpos =(self._last_blit_rect.x, self._last_blit_rect.y)
-                    self._last_blit_rect.x -= self.parent.x
-                    self._last_blit_rect.y -= self.parent.y
-                    util.blit(self.parent.surface, lbrpos,
+                    self._last_blit_rect.x -= self.container.x
+                    self._last_blit_rect.y -= self.container.y
+                    util.blit(self.container.surface, lbrpos,
                             clip_rect=self._last_blit_rect)
 
                 #clip_rect = surf.get_rect()
